===============================
 Textual Specification Checker
===============================

.. image:: https://travis-ci.org/ftrader/spec_checker.png
   :target: https://travis-ci.org/ftrader/spec_checker

This project provides a simple tool to check textual requirement and design
specifications for consistency.

As a future optional feature, it is planned to enhance it to check that
design elements are referenced in corresponding source code, to check
full traceability from requirements to design to source.

It is being developed to ensure that specifications and source for
developed `BTCfork`_ Bitcoin spin-off prototypes remain consistent and
complete.


.. _BTCfork: http://github.com/btcfork/


Usage
=====

To be completed.

Issues
======

Please report any bugs or requests that you have using the GitHub issue tracker!

License
=======

The spec-checker code is licensed under the GNU Affero General Public
License version 3 (AGPLv3). See LICENSE file for the detailed terms of
this license.

Authors
=======

* freetrader
